3D Apple core correction
------------------------
The missing apple core (in Fourier space) leads to ringing and blurring
artifacts in optical diffraction tomography :cite:`Vertu2009`.
This module contains basic functions that can be used to attenuate
these artifacts.

.. versionadded:: 0.3.0

.. versionchanged:: 0.4.0

.. automodule:: odtbrain.apple
    :members:
